<?php

namespace Drupal\mollie_commerce\EventSubscriber;

use Drupal\commerce_order\Entity\Order;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\HttpKernel\HttpKernelInterface;

/**
 * Base class for Mollie event subscribers.
 */
class MollieEventSubscriberBase {

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * HTTP kernel.
   *
   * @var \Symfony\Component\HttpKernel\HttpKernelInterface
   */
  protected $httpKernel;

  /**
   * MollieRedirectEventSubscriber constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager.
   *
   * @param \Symfony\Component\HttpKernel\HttpKernelInterface $httpKernel
   *   HTTP kernel.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, HttpKernelInterface $httpKernel) {
    $this->entityTypeManager = $entityTypeManager;
    $this->httpKernel = $httpKernel;
  }

  /**
   * Returns the payment gateway ID for a Commerce order.
   *
   * @param string $order_id
   *   The Commerce order ID.
   *
   * @return string|null
   *   The ID of the payment gateway, or NULL if not found.
   */
  protected function getCommercePaymentGatewayIdByOrderId(string $order_id): ?string {
    $order = $this->getCommerceOrder($order_id);
    if (!$order) {
      return NULL;
    }

    return $order->get('payment_gateway')->target_id;
  }

  /**
   * Returns a Commerce order by ID.
   *
   * @param string $order_id
   *   The Commerce order ID.
   *
   * @return \Drupal\commerce_order\Entity\Order|null
   *   The Commerce order, or NULL if not found.
   */
  protected function getCommerceOrder(string $order_id): ?Order {
    return $this->entityTypeManager->getStorage('commerce_order')
      ->load($order_id);
  }

}
