<?php

namespace Drupal\mollie_webform;

use Drupal\webform\WebformSubmissionInterface;

/**
 * Provides some helper methods for the Mollie for Drupal Webform module.
 */
class MollieWebformHelper {

  /**
   * Returns the machine name of the status element on a webform by submission.
   *
   * @param \Drupal\webform\WebformSubmissionInterface $submission
   *   A submission submitted for the webform.
   *
   * @return string|null
   *   The machine name of the Mollie transaction status element. Or null when
   *   na such element was found on the webform.
   */
  public function getMolliePaymentStatusElementNameFromWebformSubmission(WebformSubmissionInterface $submission): ?string {
    $elements = $submission->getWebform()->getElementsDecoded();
    foreach ($elements as $name => $element) {
      if ('mollie_payment_status' === $element['#type']) {
        // We assume that there is only one element for the Mollie payment
        // status. If there happen to be more the transactions' status is stored
        // in the first one returned by
        // \Drupal\webform\WebformInterface::getElementsDecoded().
        return $name;
      }
    }

    return NULL;
  }

}
