<?php

namespace Drupal\mollie_webform\Plugin\WebformElement;

use Drupal\webform\Plugin\WebformElement\Value;
use Drupal\webform\WebformSubmissionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'mollie_payment_status' element.
 *
 * We define a custom element so that we can identify the element in the webform
 * independent of the (machine) name it gets in the form.
 *
 * @WebformElement(
 *   id = "mollie_payment_status",
 *   label = @Translation("Mollie payment status"),
 *   description = @Translation("Element to store the status of a Mollie payment. Should be used in combination with the Mollie payment handler."),
 *   category = @Translation("Mollie"),
 * )
 */
class MolliePaymentStatus extends Value {

  /**
   * The Mollie service.
   *
   * @var \Drupal\mollie\Mollie
   */
  protected $mollie;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): MolliePaymentStatus {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);

    $instance->mollie = $container->get('mollie.mollie');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function formatTextItem(array $element, WebformSubmissionInterface $webform_submission, array $options = []) {
    $value = parent::formatTextItem($element, $webform_submission, $options);

    // Turn the value into a Mollie payment status label.
    $payment_statuses = $this->mollie->getStatuses();
    return $payment_statuses[$value] ?? '';
  }

}
